import React, { useEffect, useState } from "react";
import ToggleHeader from "../../ui/inputs/ToggleHeader";
import Outline from "./Outline";
import Header from "./Header";
import useToggleStore from "../../../store/useUIToggleStore";
import Assets from "./Assets";
import useModuleStore from "../../../store/useModuleStore";

const SideBarLeft: React.FC = () => {
  const [activeOption, setActiveOption] = useState("Outline");

  const { toggleUI } = useToggleStore();
  const { activeModule } = useModuleStore();

  // Reset activeList whenever activeModule changes
  useEffect(() => {
    setActiveOption("Outline");
  }, [activeModule]);

  const handleToggleClick = (option: string) => {
    setActiveOption(option); // Update the active option
  };
  return (
    <div className="sidebar-left-wrapper">
      <Header />
      {toggleUI && (
        <div className="sidebar-left-container">
          {activeModule === "visualization" ? (
            <>
              <ToggleHeader
                options={["Outline", "Widgets", "Templates"]}
                activeOption={activeOption}
                handleClick={handleToggleClick}
              />
            </>
          ) : (
            <>
              <ToggleHeader
                options={["Outline", "Assets"]}
                activeOption={activeOption}
                handleClick={handleToggleClick}
              />
              <div className="sidebar-left-content-container">
                {activeOption === "Outline" ? <Outline /> : <Assets />}
              </div>
            </>
          )}
        </div>
      )}
    </div>
  );
};

export default SideBarLeft;
